@@ -3,8 +3,12 @@ from py_book_util.image_recognizer import ImageRecognizer
 import os
 import json
 from myst_nb import glue
+
+
 class PageRecognizer(object):
-    def __init__(self, cur_pages_dir, cur_page_idx, cur_page_width=2561, cur_page_height=1206):
+    def __init__(
+        self, cur_pages_dir, cur_page_idx, cur_page_width=2561, cur_page_height=1206
+    ):
         self.page_width = cur_page_width
         self.page_height = cur_page_height
         self.pages_dir = cur_pages_dir
@@ -13,29 +17,57 @@ class PageRecognizer(object):
         dst_img_dir = self.dst_img_dir()
         if os.path.isdir(dst_img_dir) == False:
             os.mkdir(dst_img_dir)
+
     def cur_img_file(self):
         return "%s/%s.png" % (self.pages_dir, self.page_idx)
+
     def dst_img_dir(self):
         return "%s/%s" % (self.pages_dir, self.page_idx)
-    def recognize_rect(self, cur_key_word, crop_img_top, crop_img_bottom, crop_img_left, crop_img_right, post_replace={}, flag_force = False, ratio="2.0", flag_autocrop = True, app_name="img2txt"):
-        cur_rec = ImageRecognizer("%s.png"%cur_key_word, crop_img_top, crop_img_bottom, crop_img_left, crop_img_right, self.cur_img_file(), self.dst_img_dir(), flag_force, ratio, flag_autocrop)
+
+    def recognize_rect(
+        self,
+        cur_key_word,
+        crop_img_top,
+        crop_img_bottom,
+        crop_img_left,
+        crop_img_right,
+        post_replace={},
+        flag_force=False,
+        ratio="2.0",
+        flag_autocrop=True,
+        app_name="img2txt",
+    ):
+        cur_rec = ImageRecognizer(
+            "%s.png" % cur_key_word,
+            crop_img_top,
+            crop_img_bottom,
+            crop_img_left,
+            crop_img_right,
+            self.cur_img_file(),
+            self.dst_img_dir(),
+            flag_force,
+            ratio,
+            flag_autocrop,
+        )
         cur_rec_data = cur_rec.recognize_text(app_name)
         for single_replace_key in post_replace:
-            cur_rec_data['recognize_text'] = cur_rec_data['recognize_text'].replace(single_replace_key, post_replace[single_replace_key]) # ("\u2014", "-")        
-        glue(cur_key_word, cur_rec_data['recognize_text'])
-        self.page_elements[cur_key_word] = cur_rec_data        
+            cur_rec_data["recognize_text"] = cur_rec_data["recognize_text"].replace(
+                single_replace_key, post_replace[single_replace_key]
+            )  # ("\u2014", "-")
+        glue(cur_key_word, cur_rec_data["recognize_text"])
+        self.page_elements[cur_key_word] = cur_rec_data
         return cur_rec
 
     def generate_html_js(self, element_height={}):
         self.generate_js(element_height)
         self.generate_html()
-        
+
     def generate_js(self, element_height={}):
-        file_name_page_js = "%s.js"%self.cur_img_file()
+        file_name_page_js = "%s.js" % self.cur_img_file()
         if os.path.isfile(file_name_page_js):
             os.remove(file_name_page_js)
         cur_page_elements_js = ""
-        # cur_page_ratio = cur_page_width / 1280
+        # cur_page_ratio = self.page_width / 1280
         cur_page_element_top = 0
         cur_page_element_height = 0
         cur_page_element_idx = 0
@@ -43,20 +75,43 @@ class PageRecognizer(object):
             cur_page_element_idx = cur_page_element_idx + 1
             cur_page_element_top = cur_page_element_top + cur_page_element_height + 10
             cur_page_element_height = 60
-            if single_element in element_height :
+            if single_element in element_height:
                 cur_page_element_height = element_height[single_element]
             single_data = self.page_elements[single_element]
             print(single_element)
             print(single_data)
-            cur_page_elements_js = cur_page_elements_js + """
+            cur_page_elements_js = (
+                cur_page_elements_js
+                + """
 image_note.add(new DoneElement(%d / 2, %d / 2, %d / 2, %d / 2, "%s<br/>%s"));
-""" % (single_data["crop_img_left"], single_data["crop_img_top"], 
-       cur_page_width - single_data["crop_img_right"] - single_data["crop_img_left"], 
-       cur_page_height - single_data["crop_img_bottom"] - single_data["crop_img_top"], 
-       single_element, single_data["recognize_text"])
-            cur_page_elements_js = cur_page_elements_js + """
+"""
+                % (
+                    single_data["crop_img_left"],
+                    single_data["crop_img_top"],
+                    self.page_width
+                    - single_data["crop_img_right"]
+                    - single_data["crop_img_left"],
+                    self.page_height
+                    - single_data["crop_img_bottom"]
+                    - single_data["crop_img_top"],
+                    single_element,
+                    single_data["recognize_text"],
+                )
+            )
+            cur_page_elements_js = (
+                cur_page_elements_js
+                + """
 image_note.add(new CommentElement(1300, 30+%d, 250, 44+%d, "Note_%s_%03d:<br/> - %s<br/> - %s"));
-""" % (cur_page_element_top, cur_page_element_height - 44, self.page_idx, cur_page_element_idx, single_element, single_data["recognize_text"])
+"""
+                % (
+                    cur_page_element_top,
+                    cur_page_element_height - 44,
+                    self.page_idx,
+                    cur_page_element_idx,
+                    single_element,
+                    single_data["recognize_text"],
+                )
+            )
         file_content_page_js = """
 var currentScript = $('script').last();
 
@@ -71,13 +126,16 @@ $(document).ready(function () {
 
   image_note.create();
 });
-""" % (self.page_idx, cur_page_elements_js)
+""" % (
+            self.page_idx,
+            cur_page_elements_js,
+        )
         util.create_text_file(file_name_page_js, file_content_page_js)
         # util.display_code(file_name_page_js)
         # print("http://localhost:4507/xxx_dev_blog/%s/%s.png.html" % (self.pages_dir, self.page_idx))
 
     def generate_html(self):
-        file_name_page_html = "%s.html"%self.cur_img_file()
+        file_name_page_html = "%s.html" % self.cur_img_file()
         if os.path.isfile(file_name_page_html):
             os.remove(file_name_page_html)
         file_content_page_html = """<html>
@@ -95,7 +153,11 @@ $(document).ready(function () {
     </div>
   </body>
 </html>
-""" % (self.page_idx, self.page_idx, self.page_idx)
+""" % (
+            self.page_idx,
+            self.page_idx,
+            self.page_idx,
+        )
         util.create_text_file(file_name_page_html, file_content_page_html)
         # util.display_code(file_name_page_html)
         # print("http://localhost:4507/xxx_dev_blog/%s/%s.png.html" % (self.pages_dir, self.page_idx))
